@@ -1,13 +1,13 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2014-10-31'; # DATE
-our $VERSION = '0.42'; # VERSION
+our $DATE = '2014-11-07'; # DATE
+our $VERSION = '0.43'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
 # use warnings; # already enabled by Mo
 
-use Mo;
+use Mo qw(build default);
 #use Moo;
 extends 'Perinci::CmdLine::Base';
 
@@ -19,17 +19,43 @@ has default_prompt_template => (
     is=>'rw',
     default => 'Enter %s: ',
 );
+has log => (
+    is=>'rw',
+    default => sub {
+        if (defined $ENV{LOG}) {
+            return $ENV{LOG};
+        } elsif ($ENV{LOG_LEVEL} && $ENV{LOG_LEVEL} =~ /^(off|none)$/) {
+            return 0;
+        } elsif ($ENV{LOG_LEVEL} || $ENV{TRACE} || $ENV{DEBUG} ||
+                     $ENV{VERBOSE} || $ENV{QUIET}) {
+            return 0;
+        }
+        0;
+    },
+);
+has log_level => (
+    is=>'rw',
+    default => sub {
+        if ($ENV{LOG_LEVEL}) {
+            return $ENV{LOG_LEVEL};
+        } elsif ($ENV{TRACE}) {
+            return 'trace';
+        } elsif ($ENV{DEBUG}) {
+            return 'debug';
+        } elsif ($ENV{VERBOSE}) {
+            return 'info';
+        } elsif ($ENV{QUIET}) {
+            return 'error';
+        }
+        'warning';
+    },
+);
 
 my $formats = [qw/text text-simple text-pretty json json-pretty/];
 
 sub BUILD {
     my ($self, $args) = @_;
 
-    # default doesn't work?
-    if (!$self->{default_prompt_template}) {
-        $self->{default_prompt_template} = 'Enter %s: ';
-    }
-
     if (!$self->{riap_client}) {
         require Perinci::Access::Lite;
         my %rcargs = (
@@ -142,6 +168,48 @@ sub BUILD {
                 },
             };
         }
+        if ($self->log) {
+            $co->{log_level} = {
+                getopt  => 'log-level=s',
+                summary => 'Set log level',
+                handler => sub {
+                    my ($go, $val, $r) = @_;
+                    $r->{log_level} = $val;
+                },
+            };
+            $co->{trace} = {
+                getopt  => 'trace',
+                summary => "Set log level to 'trace'",
+                handler => sub {
+                    my ($go, $val, $r) = @_;
+                    $r->{log_level} = 'trace';
+                },
+            };
+            $co->{debug} = {
+                getopt  => 'debug',
+                summary => "Set log level to 'debug'",
+                handler => sub {
+                    my ($go, $val, $r) = @_;
+                    $r->{log_level} = 'debug';
+                },
+            };
+            $co->{verbose} = {
+                getopt  => 'verbose',
+                summary => "Set log level to 'info'",
+                handler => sub {
+                    my ($go, $val, $r) = @_;
+                    $r->{log_level} = 'info';
+                },
+            };
+            $co->{quiet} = {
+                getopt  => 'quiet',
+                summary => "Set log level to 'error'",
+                handler => sub {
+                    my ($go, $val, $r) = @_;
+                    $r->{log_level} = 'error';
+                },
+            };
+        }
         $self->{common_opts} = $co;
     }
 
@@ -170,6 +238,14 @@ sub hook_after_parse_argv {
         }
     }
 
+    # set up log adapter
+    if ($self->log) {
+        require Log::Any::Adapter;
+        Log::Any::Adapter->set(
+            'ScreenColoredLevel',
+            min_level => $r->{log_level} // $self->log_level,
+        );
+    }
 }
 
 sub hook_format_result {
@@ -531,7 +607,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.42 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2014-10-31.
+This document describes version 0.43 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2014-11-07.
 
 =head1 SYNOPSIS
 
@@ -551,6 +627,9 @@ L<Perinci::Access> for metadata access, L<Data::Sah> for validator generation,
 L<Text::ANSITable> for formatting results, and L<Log::Any::App> (which uses
 L<Log::Log4perl>) for logging.
 
+P::C::Lite attributes default to condition of low startup overhead. For example,
+C<log> is by default off instead of on like in P::C.
+
 I first developed P::C::Lite mainly for CLI applications that utilize shell tab
 completion as their main feature, e.g. L<App::PMUtils>, L<App::ProgUtils>,
 L<App::GitUtils>.
@@ -610,13 +689,10 @@ Perinci::Access::Lite) adds too much startup overhead.
 
 =item * P::C::Lite does not support undo
 
-=item * P::C::Lite does not currently support logging
+=item * P::C::Lite currently has simpler logging
 
-Something more lightweight than L<Log::Any::App> will be considered. But for
-now, if you want to view logging and your function uses L<Log::Any>, you can do
-something like this:
-
- % DEBUG=1 PERL5OPT=-MLog::Any::App app.pl
+Only logging to screen is supported, using
+L<Log::Any::Adapter::ScreenColoredLevel>.
 
 =item * P::C::Lite does not support progress indicator
 
@@ -630,8 +706,6 @@ something like this:
  COLOR
  UTF8
 
- DEBUG, VERBOSE, QUIET, TRACE, and so on
-
 =item * In passing command-line object to functions, P::C::Lite object is passed
 
 Some functions might expect a L<Perinci::CmdLine> instance.
@@ -644,25 +718,48 @@ Some functions might expect a L<Perinci::CmdLine> instance.
 
 All the attributes of L<Perinci::CmdLine::Base>, plus:
 
-=over
+=head2 log => bool (default: 0, or from env)
 
-=back
+Whether to enable logging. This currently means setting up L<Log::Any::Adapter>
+to display logging (set in C<hook_after_parse_argv>, so tab completion skips
+this step). To produce log, you use L<Log::Any> in your code.
+
+The default is off. If you set LOG=1 or LOG_LEVEL or TRACE/DEBUG/VERBOSE/QUIET,
+then the default will be on. It defaults to off if you set LOG=0 or
+LOG_LEVEL=off.
+
+=head2 log_level => str (default: warning, or from env)
+
+Set default log level. The default can also be set via
+LOG_LEVEL/TRACE/DEBUG/VERBOSE/QUIET.
 
 =head1 METHODS
 
 All the methods of L<Perinci::CmdLine::Base>, plus:
 
-=over
-
-=back
-
 =head1 ENVIRONMENT
 
 All the environment variables that L<Perinci::CmdLine::Base> supports, plus:
 
-=over
+=head2 DEBUG
 
-=back
+Set log level to 'debug'.
+
+=head2 VERBOSE
+
+Set log level to 'info'.
+
+=head2 QUIET
+
+Set log level to 'error'.
+
+=head2 TRACE
+
+Set log level to 'trace'.
+
+=head2 LOG_LEVEL
+
+Set log level.
 
 =head1 RESULT METADATA
 
